<?php
// Функция для чтения CSV файлов и преобразования их в массив
function readCSV($filename) {
    $rows = array_map('str_getcsv', file($filename));
    $header = array_shift($rows);
    $csv = [];
    foreach ($rows as $row) {
        $csv[] = array_combine($header, $row);
    }
    return $csv;
}

// Функция для замены спинов в тексте
function processSpins($text) {
    return preg_replace_callback('/{([^{}]+)}/', function($matches) {
        $choices = explode('|', $matches[1]);
        return $choices[array_rand($choices)];
    }, $text);
}

// Функция для генерации случайной строки
function randomString($length = 4, $chars = 'abcdefghijklmnopqrstuvwxyz', $capitalizeFirst = false) {
    $randomString = substr(str_shuffle($chars), 0, $length);
    if ($capitalizeFirst) {
        $randomString = ucfirst($randomString);
    }
    return $randomString;
}

// Функция для генерации случайного URL с дефисом
function generateUrl() {
    return randomString(4) . '-' . rand(10, 99);
}

// Функция для генерации случайного стиля с минимальным размером шрифта
function generateRandomStyle($minFontSize = '16px') {
    $fonts = ['Arial', 'Verdana', 'Helvetica', 'Georgia', 'Times New Roman'];
    $sizes = ['16px', '18px', '20px', '24px']; // Удалены размеры меньше 16px
    $margins = ['5px', '10px', '15px', '20px'];
    $styles = [
        'font-family' => $fonts[array_rand($fonts)],
        'font-size' => $sizes[array_rand($sizes)], // Гарантирует минимальный размер шрифта 16px
        'margin' => $margins[array_rand($margins)]
    ];
    $styleString = '';
    foreach ($styles as $key => $value) {
        $styleString .= "$key: $value; ";
    }
    return $styleString;
}

// Функция для генерации таблицы
function generateTable($data, $numRows) {
    $headers = array_keys($data[0]);
    $rows = array_rand($data, $numRows);
    $table = '<table border="1" style="' . generateRandomStyle() . '"><tr>';
    foreach ($headers as $header) {
        $table .= "<th style=\"" . generateRandomStyle() . "\">$header</th>";
    }
    $table .= '</tr>';
    foreach ($rows as $row) {
        $table .= '<tr>';
        foreach ($data[$row] as $cell) {
            $table .= "<td style=\"" . generateRandomStyle() . "\">$cell</td>";
        }
        $table .= '</tr>';
    }
    $table .= '</table>';
    return $table;
}

// Чтение CSV файлов
$banks = readCSV('data/banks.csv');
$mfo = readCSV('data/mfo.csv');
$keysMfo = array_map('str_getcsv', file('data/keys-mfo.csv'));
$keysBanks = array_map('str_getcsv', file('data/keys-banks.csv'));
$links = readCSV('data/links.csv');

// Обновление счетчика посещений
$countFile = 'count.txt';
if (file_exists($countFile)) {
    $count = file_get_contents($countFile);
    if (is_numeric($count)) {
        $count = (int)$count;
        $count++;
        file_put_contents($countFile, $count);
    }
}

// Получение URL
$url = parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH);
$url = ltrim($url, '/');

// Проверка URL-адреса для robots.txt
if ($url === 'robots.txt') {
    header('Content-Type: text/plain; charset=UTF-8');
    $randomBot = randomString(4, 'abcdefghijklmnopqrstuvwxyz', true);
    echo "User-agent: *\n";
    echo "Disallow: /\n\n";
    echo "User-Agent: GoogleBot\n";
    echo "Allow: /\n\n";
    echo "User-Agent: Yandex\n";
    echo "Allow: /\n\n";
    echo "User-agent: $randomBot Bot\n";
    echo "Disallow: /\n";
    exit;
}

// Проверка URL-адреса
if (ctype_digit($url)) {
    $linkIndex = array_search($url, array_column($links, 'Page'));

    if ($linkIndex !== false) {
        $linkInfo = $links[$linkIndex];
        $pageTitle = $linkInfo['Title'] . ' - ' . $keysMfo[array_rand($keysMfo)][0];
        $h1 = $linkInfo['Title'];
        $source = "Источник: {$linkInfo['Link']} сайт.";

        // Генерация основного контента
        $randomKeyMfo = $keysMfo[array_rand($keysMfo)][0];
        $randomKeyBanks = $keysBanks[array_rand($keysBanks)][0];
        $textFiles = ['text1.txt', 'text2.txt', 'text3.txt'];
        $textContent = file_get_contents($textFiles[array_rand($textFiles)]);
        $textContent = str_replace('%key%', $h1, $textContent);
        $textContent = processSpins($textContent);

        $h2Mfo = $keysMfo[array_rand($keysMfo)][0];
        $h2MfoLink = '<a href="/" style="' . generateRandomStyle() . '">'.$h2Mfo.'</a>';
        $h2Banks = $keysBanks[array_rand($keysBanks)][0];

        $mfoTable = generateTable($mfo, rand(10, 20));
        $banksTable = generateTable($banks, rand(10, 20));

        $externalLink = '';
        if (rand(1, 100) === 1) {
            $domain = randomString(3, 'abcdefghijklmnopqrstuvwxyz', true) . '.' . ['ru', 'com', 'net', 'org', 'info', 'site'][array_rand(['ru', 'com', 'net', 'org', 'info', 'site'])];
            $url = "https://$domain";
            $externalLink = "<a href=\"$url\" style=\"" . generateRandomStyle() . "\">$url</a>";
        }

        $additionalContent = '';
        if (rand(1, 10) === 1) {
            $additionalH2 = $keysMfo[array_rand($keysMfo)][0];
            $additionalTextFile = $textFiles[array_rand($textFiles)];
            $additionalTextContent = file_get_contents($additionalTextFile);
            $additionalTextContent = str_replace('%key%', $additionalH2, $additionalTextContent);
            $additionalTextContent = processSpins($additionalTextContent);
            $additionalContent = "<h2 style=\"" . generateRandomStyle() . "\">$additionalH2</h2><div style=\"" . generateRandomStyle() . "\">$additionalTextContent</div>";
        }

        // Генерация случайных внутренних ссылок
        $numLinks = rand(2, 5);
        $randomInternalLinks = '<ul>';
        for ($i = 0; $i < $numLinks; $i++) {
            $url = generateUrl();
            $anchor = substr($url, 1); // Убираем начальный слеш
            $randomInternalLinks .= "<li><a href=\"/$url\" style=\"" . generateRandomStyle() . "\">$anchor</a></li>";
        }
        $randomInternalLinks .= '</ul>';

        // Генерация HTML страницы для URL, начинающегося с цифры
        $html = "<!DOCTYPE html>
        <html lang=\"ru\">
        <head>
            <meta charset=\"UTF-8\">
            <title>$pageTitle</title>
        </head>
        <body>
            <h1 style=\"" . generateRandomStyle() . "\">$h1</h1>
            <p style=\"" . generateRandomStyle() . "\">$source</p>
            <div style=\"" . generateRandomStyle() . "\">$textContent</div>
            <h2 style=\"" . generateRandomStyle() . "\">$h2MfoLink</h2>
            $mfoTable
            <h2 style=\"" . generateRandomStyle() . "\">$h2Banks</h2>
            $banksTable
            <div style=\"" . generateRandomStyle() . "\">$externalLink</div>
            $additionalContent
            <div style=\"" . generateRandomStyle() . "\">$randomInternalLinks</div>
        </body>
        </html>";
        echo $html;
        exit;
    }
}

// Генерация заголовков для остальных страниц
$randomKeyMfo = $keysMfo[array_rand($keysMfo)][0];
$randomKeyBanks = $keysBanks[array_rand($keysBanks)][0];
$pageTitle = $randomKeyMfo . ' - ' . $randomKeyBanks;
$h1 = $randomKeyMfo;

// Чтение текстов с подстановками спинов
$textFiles = ['text1.txt', 'text2.txt', 'text3.txt'];
$textContent = file_get_contents($textFiles[array_rand($textFiles)]);
$textContent = str_replace('%key%', $h1, $textContent);
$textContent = processSpins($textContent);

// Генерация H2 заголовков и таблиц
$h2Mfo = $keysMfo[array_rand($keysMfo)][0];
$h2MfoLink = '<a href="/" style="' . generateRandomStyle() . '">'.$h2Mfo.'</a>'; // H2 с ссылкой на главную страницу
$h2Banks = $keysBanks[array_rand($keysBanks)][0];

$mfoTable = generateTable($mfo, rand(10, 20));
$banksTable = generateTable($banks, rand(10, 20));

// Генерация внутренних ссылок
shuffle($links);
$internalLinks = '<ul>';
foreach ($links as $link) {
    if ($link['Page'] !== $url) {
        $page = $link['Page'];
        $linkTitle = $link['Title'];
        $internalLinks .= "<li><a href=\"/$page\" style=\"" . generateRandomStyle() . "\">$linkTitle</a></li>";
    }
}
$internalLinks .= '</ul>';

// Генерация случайных внутренних ссылок в конце страницы
$numLinks = rand(2, 5);
$randomInternalLinks = '<ul>';
for ($i = 0; $i < $numLinks; $i++) {
    $url = generateUrl();
    $anchor = substr($url, 1); // Убираем начальный слеш
    $randomInternalLinks .= "<li><a href=\"/$url\" style=\"" . generateRandomStyle() . "\">$anchor</a></li>";
}
$randomInternalLinks .= '</ul>';

// Генерация внешней ссылки с вероятностью 1%
$externalLink = '';
if (rand(1, 100) === 1) {
    $domain = randomString(3, 'abcdefghijklmnopqrstuvwxyz', true) . '.' . ['ru', 'com', 'net', 'org', 'info', 'site'][array_rand(['ru', 'com', 'net', 'org', 'info', 'site'])];
    $url = "https://$domain";
    $externalLink = "<a href=\"$url\" style=\"" . generateRandomStyle() . "\">$url</a>";
}

// Генерация дополнительного блока с вероятностью 10%
$additionalContent = '';
if (rand(1, 10) === 1) {
    $additionalH2 = $keysMfo[array_rand($keysMfo)][0];
    $additionalTextFile = $textFiles[array_rand($textFiles)];
    $additionalTextContent = file_get_contents($additionalTextFile);
    $additionalTextContent = str_replace('%key%', $additionalH2, $additionalTextContent);
    $additionalTextContent = processSpins($additionalTextContent);
    $additionalContent = "<h2 style=\"" . generateRandomStyle() . "\">$additionalH2</h2><div style=\"" . generateRandomStyle() . "\">$additionalTextContent</div>";
}

// Генерация HTML страницы для остальных страниц
$html = "<!DOCTYPE html>
<html lang=\"ru\">
<head>
    <meta charset=\"UTF-8\">
    <title>$pageTitle</title>
</head>
<body>
    <h1 style=\"" . generateRandomStyle() . "\">$h1</h1>
    <div style=\"" . generateRandomStyle() . "\">$internalLinks</div>
    <div style=\"" . generateRandomStyle() . "\">$textContent</div>
    <h2 style=\"" . generateRandomStyle() . "\">$h2MfoLink</h2>
    $mfoTable
    <h2 style=\"" . generateRandomStyle() . "\">$h2Banks</h2>
    $banksTable
    <div style=\"" . generateRandomStyle() . "\">$externalLink</div>
    $additionalContent
    <div style=\"" . generateRandomStyle() . "\">$randomInternalLinks</div>
</body>
</html>";

// Вывод HTML
echo $html;
?>

